"use strict";
/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const getValue = (key, data, params, keySeparator = ".", keyValueSeparator = "@@") => {
  let defaultValue = void 0;
  [key, defaultValue] = separateKeyValue(key, keyValueSeparator);
  const value = key.split(keySeparator).reduce((acc, cur) => acc && acc[cur] !== void 0 ? acc[cur] : void 0, data);
  if (value) {
    if (typeof value === "string")
      return params ? transpileParams(value, params) : value;
    if (typeof value === "object")
      return params ? JSON.parse(transpileParams(JSON.stringify(value), params)) : value;
  }
  if (defaultValue) {
    if (!/^[[{].*[\]}]$/.test(defaultValue) || /^{{/.test(defaultValue))
      return params ? transpileParams(defaultValue, params) : defaultValue;
    return params ? JSON.parse(transpileParams(defaultValue, params)) : JSON.parse(defaultValue);
  }
  return key;
};
const separateKeyValue = (key, keyValueSeparator = "@@") => {
  return key.split(keyValueSeparator);
};
const transpileParams = (value, params) => {
  const replacedValue = value.replace(/{{\s?([^{}\s]*)\s?}}/g, (substring, parsedKey) => {
    const replacer = params[parsedKey];
    return replacer !== void 0 ? replacer : substring;
  });
  return replacedValue;
};
exports.getValue = getValue;
exports.separateKeyValue = separateKeyValue;
exports.transpileParams = transpileParams;
