"use strict";
/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const core = require("./core.qwik.cjs");
const context = require("./context.qwik.cjs");
const inlinePlural = () => {
  const currentLang = context.getLang();
  const plural = (value, key, params, options, lang) => {
    const { translation, config } = context.getSpeakContext();
    lang ?? (lang = currentLang);
    value = +value;
    const rule = new Intl.PluralRules(lang, options).select(value);
    let defaultValues = void 0;
    if (key) {
      [key, defaultValues] = core.separateKeyValue(key, config.keyValueSeparator);
      if (!defaultValues && /^{.*}$/.test(key)) {
        defaultValues = key;
        key = void 0;
      }
    }
    key = key ? `${key}${config.keySeparator}${rule}` : rule;
    const defaultValue = defaultValues ? JSON.parse(defaultValues)[rule] : void 0;
    if (defaultValue)
      key = `${key}${config.keyValueSeparator}${defaultValue}`;
    return core.getValue(key, translation[lang], {
      value,
      ...params
    }, config.keySeparator, config.keyValueSeparator);
  };
  return plural;
};
exports.inlinePlural = inlinePlural;
