/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
import { separateKeyValue, getValue } from "./core.qwik.mjs";
import { getLang, getSpeakContext } from "./context.qwik.mjs";
const inlinePlural = () => {
  const currentLang = getLang();
  const plural = (value, key, params, options, lang) => {
    const { translation, config } = getSpeakContext();
    lang ?? (lang = currentLang);
    value = +value;
    const rule = new Intl.PluralRules(lang, options).select(value);
    let defaultValues = void 0;
    if (key) {
      [key, defaultValues] = separateKeyValue(key, config.keyValueSeparator);
      if (!defaultValues && /^{.*}$/.test(key)) {
        defaultValues = key;
        key = void 0;
      }
    }
    key = key ? `${key}${config.keySeparator}${rule}` : rule;
    const defaultValue = defaultValues ? JSON.parse(defaultValues)[rule] : void 0;
    if (defaultValue)
      key = `${key}${config.keyValueSeparator}${defaultValue}`;
    return getValue(key, translation[lang], {
      value,
      ...params
    }, config.keySeparator, config.keyValueSeparator);
  };
  return plural;
};
export {
  inlinePlural
};
