"use strict";
/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const build = require("@builder.io/qwik/build");
const context = require("./context.qwik.cjs");
const log = require("./log.qwik.cjs");
const cache = {};
const memoize = (fn) => {
  return (...args) => {
    const stringArgs = JSON.stringify(args);
    return stringArgs in cache ? cache[stringArgs] : cache[stringArgs] = fn(...args);
  };
};
const loadTranslations = async (ctx, assets, runtimeAssets, langs) => {
  if (build.isServer || runtimeAssets) {
    const { locale, translation, translationFn, config } = ctx;
    const { translation: _translation } = context.getSpeakContext();
    if (build.isDev) {
      const conflictingAsset = assets?.find((asset) => runtimeAssets?.includes(asset)) || assets?.find((asset) => config.runtimeAssets?.includes(asset)) || runtimeAssets?.find((asset) => config.assets?.includes(asset));
      if (conflictingAsset)
        log.logWarn(`Conflict between assets and runtimeAssets '${conflictingAsset}'`);
    }
    let resolvedAssets;
    if (build.isServer)
      resolvedAssets = [
        ...assets ?? [],
        ...runtimeAssets ?? []
      ];
    else
      resolvedAssets = [
        ...runtimeAssets ?? []
      ];
    if (resolvedAssets.length === 0)
      return;
    const resolvedLangs = new Set(langs || []);
    resolvedLangs.add(locale.lang);
    for (const lang of resolvedLangs) {
      let tasks;
      if (!build.isDev) {
        const memoized = memoize(translationFn.loadTranslation$);
        tasks = resolvedAssets.map((asset) => memoized(lang, asset));
      } else
        tasks = resolvedAssets.map((asset) => translationFn.loadTranslation$(lang, asset));
      const sources = await Promise.all(tasks);
      const assetSources = sources.map((source, i) => ({
        asset: resolvedAssets[i],
        source
      }));
      if (!(lang in _translation))
        Object.assign(_translation, {
          [lang]: {}
        });
      for (const data of assetSources)
        if (data?.source) {
          if (build.isServer) {
            if (assets?.includes(data.asset))
              Object.assign(_translation[lang], data.source);
            else {
              Object.assign(_translation[lang], data.source);
              Object.assign(translation[lang], data.source);
            }
          } else
            Object.assign(_translation[lang], data.source);
        }
    }
  }
};
exports.loadTranslations = loadTranslations;
exports.memoize = memoize;
