"use strict";
/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const qwik = require("@builder.io/qwik");
const build = require("@builder.io/qwik/build");
const context = require("./context.qwik.cjs");
const load = require("./load.qwik.cjs");
const log = require("./log.qwik.cjs");
const useQwikSpeak = (props) => {
  const lang = qwik.getLocale("");
  const resolvedConfig = {
    rewriteRoutes: props.config.rewriteRoutes,
    defaultLocale: props.config.defaultLocale,
    supportedLocales: props.config.supportedLocales,
    assets: props.config.assets,
    runtimeAssets: props.config.runtimeAssets,
    keySeparator: props.config.keySeparator || ".",
    keyValueSeparator: props.config.keyValueSeparator || "@@",
    domainBasedRouting: props.config.domainBasedRouting,
    showDebugMessagesLocally: props.config.showDebugMessagesLocally ?? true
  };
  let resolvedLocale = resolvedConfig.supportedLocales.find((value) => value.lang === lang);
  if (!resolvedLocale) {
    resolvedLocale = resolvedConfig.defaultLocale;
    if (build.isDev)
      log.logWarn(`Locale not resolved. Fallback to default locale: ${resolvedConfig.defaultLocale.lang}`);
  } else if (build.isDev)
    log.logDebug(resolvedConfig.showDebugMessagesLocally, `Resolved locale: ${resolvedLocale.lang}`);
  if (props.currency)
    resolvedLocale.currency = props.currency;
  if (props.timeZone)
    resolvedLocale.timeZone = props.timeZone;
  const resolvedTranslationFn = {
    loadTranslation$: props.translationFn?.loadTranslation$ ?? /* @__PURE__ */ qwik.inlinedQrl(() => null, "useQwikSpeak_resolvedTranslationFn_T9Fy9UxepgA")
  };
  const state = {
    locale: Object.assign({}, resolvedLocale),
    translation: Object.fromEntries(resolvedConfig.supportedLocales.map((value) => [
      value.lang,
      {}
    ])),
    config: Object.assign({}, resolvedConfig),
    translationFn: resolvedTranslationFn
  };
  const { config } = state;
  context.setSpeakServerContext(config);
  context.setGetLangFn(() => qwik.getLocale(config.defaultLocale.lang));
  qwik.useContextProvider(context.SpeakContext, state);
  qwik.useTaskQrl(/* @__PURE__ */ qwik.inlinedQrl(async () => {
    const [config2, props2, state2] = qwik.useLexicalScope();
    if (build.isServer)
      await load.loadTranslations(state2, config2.assets, config2.runtimeAssets, props2.langs);
  }, "useQwikSpeak_useTask_0fwIeNJbECQ", [
    config,
    props,
    state
  ]));
  const resumeContext$ = /* @__PURE__ */ qwik.inlinedQrl(() => {
    const [resolvedConfig2, state2] = qwik.useLexicalScope();
    const { locale, translation, config: config2 } = state2;
    context.setSpeakClientContext(locale, translation, config2);
    context.setGetLangFn(() => locale.lang);
    if (build.isDev) {
      const _speakContext = context.getSpeakContext();
      log.logDebugInline(resolvedConfig2.showDebugMessagesLocally, "Client context", _speakContext);
    }
    if (build.isDev) {
      if (void 0) {
        (void 0).send("qwik-speak:lang", {
          msg: locale.lang
        });
        log.logDebugInline(resolvedConfig2.showDebugMessagesLocally, "Ready");
      }
    }
  }, "useQwikSpeak_resumeContext_6bH92HveK8o", [
    resolvedConfig,
    state
  ]);
  qwik.useOnWindow("load", resumeContext$);
};
const QwikSpeakMockProvider = /* @__PURE__ */ qwik.componentQrl(/* @__PURE__ */ qwik.inlinedQrl((props) => {
  const lang = props.locale?.lang;
  const resolvedConfig = {
    rewriteRoutes: props.config.rewriteRoutes,
    defaultLocale: props.config.defaultLocale,
    supportedLocales: props.config.supportedLocales,
    assets: props.config.assets,
    runtimeAssets: props.config.runtimeAssets,
    keySeparator: props.config.keySeparator || ".",
    keyValueSeparator: props.config.keyValueSeparator || "@@",
    domainBasedRouting: props.config.domainBasedRouting,
    showDebugMessagesLocally: props.config.showDebugMessagesLocally ?? true
  };
  let resolvedLocale = resolvedConfig.supportedLocales.find((value) => value.lang === lang);
  if (!resolvedLocale)
    resolvedLocale = resolvedConfig.defaultLocale;
  const resolvedTranslationFn = {
    loadTranslation$: props.translationFn?.loadTranslation$ ?? /* @__PURE__ */ qwik.inlinedQrl(() => null, "QwikSpeakMockProvider_component_resolvedTranslationFn_aOSQ00KYdkc")
  };
  const state = {
    locale: Object.assign({}, resolvedLocale),
    translation: Object.fromEntries(resolvedConfig.supportedLocales.map((value) => [
      value.lang,
      {}
    ])),
    config: Object.assign({}, resolvedConfig),
    translationFn: resolvedTranslationFn
  };
  const { locale, config } = state;
  const { config: _config } = context.getSpeakContext();
  Object.assign(_config, config);
  context.setGetLangFn(() => locale.lang);
  qwik.useContextProvider(context.SpeakContext, state);
  qwik.useTaskQrl(/* @__PURE__ */ qwik.inlinedQrl(async () => {
    const [config2, props2, state2] = qwik.useLexicalScope();
    await load.loadTranslations(state2, config2.assets, config2.runtimeAssets, props2.langs);
  }, "QwikSpeakMockProvider_component_useTask_0eOz05v4yM0", [
    config,
    props,
    state
  ]));
  return /* @__PURE__ */ qwik._jsxC(qwik.Slot, null, 3, "6l_0");
}, "QwikSpeakMockProvider_component_zQJA0JbOhj0"));
exports.QwikSpeakMockProvider = QwikSpeakMockProvider;
exports.useQwikSpeak = useQwikSpeak;
