"use strict";
/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const qwik = require("@builder.io/qwik");
const build = require("@builder.io/qwik/build");
const useFunctions = require("./use-functions.qwik.cjs");
const load = require("./load.qwik.cjs");
const context = require("./context.qwik.cjs");
const log = require("./log.qwik.cjs");
const useSpeak = (props) => {
  const ctx = useFunctions.useSpeakContext();
  const { config } = ctx;
  qwik.useTaskQrl(/* @__PURE__ */ qwik.inlinedQrl(async () => {
    const [config2, ctx2, props2] = qwik.useLexicalScope();
    if (build.isDev) {
      if (!props2.assets && !props2.runtimeAssets)
        log.logWarn("useSpeak: no assets provided");
      const duplicateAsset = config2.assets?.find((asset) => props2.assets?.includes(asset));
      if (duplicateAsset)
        log.logWarn(`useSpeak: duplicate assets '${duplicateAsset}'`);
      const duplicateRuntimeAsset = config2.runtimeAssets?.find((asset) => props2.runtimeAssets?.includes(asset));
      if (duplicateRuntimeAsset)
        log.logWarn(`useSpeak: duplicate runtimeAssets '${duplicateRuntimeAsset}'`);
    }
    await load.loadTranslations(ctx2, props2.assets, props2.runtimeAssets, props2.langs);
    if (build.isDev && build.isBrowser) {
      const _speakContext = context.getSpeakContext();
      log.logDebugInline(config2.showDebugMessagesLocally, "Client context", _speakContext);
    }
  }, "useSpeak_useTask_3ViHzm0oQjw", [
    config,
    ctx,
    props
  ]));
};
exports.useSpeak = useSpeak;
