/**
 * @license
 * Qwik Speak
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://github.com/robisim74/qwik-speak/blob/main/LICENSE
 */
import { useTaskQrl, inlinedQrl, useLexicalScope } from "@builder.io/qwik";
import { isDev, isBrowser } from "@builder.io/qwik/build";
import { useSpeakContext } from "./use-functions.qwik.mjs";
import { loadTranslations } from "./load.qwik.mjs";
import { getSpeakContext } from "./context.qwik.mjs";
import { logWarn, logDebugInline } from "./log.qwik.mjs";
const useSpeak = (props) => {
  const ctx = useSpeakContext();
  const { config } = ctx;
  useTaskQrl(/* @__PURE__ */ inlinedQrl(async () => {
    const [config2, ctx2, props2] = useLexicalScope();
    if (isDev) {
      if (!props2.assets && !props2.runtimeAssets)
        logWarn("useSpeak: no assets provided");
      const duplicateAsset = config2.assets?.find((asset) => props2.assets?.includes(asset));
      if (duplicateAsset)
        logWarn(`useSpeak: duplicate assets '${duplicateAsset}'`);
      const duplicateRuntimeAsset = config2.runtimeAssets?.find((asset) => props2.runtimeAssets?.includes(asset));
      if (duplicateRuntimeAsset)
        logWarn(`useSpeak: duplicate runtimeAssets '${duplicateRuntimeAsset}'`);
    }
    await loadTranslations(ctx2, props2.assets, props2.runtimeAssets, props2.langs);
    if (isDev && isBrowser) {
      const _speakContext = getSpeakContext();
      logDebugInline(config2.showDebugMessagesLocally, "Client context", _speakContext);
    }
  }, "useSpeak_useTask_3ViHzm0oQjw", [
    config,
    ctx,
    props
  ]));
};
export {
  useSpeak
};
